<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Yajra\Datatables\Datatables;
use App\Pilot;


class PilotController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('pilot.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('pilot.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $pilot = new Pilot;
        $pilot->name = $request->name;
        $pilot->first_name = $request->first_name;
        $pilot->ref_time = $request->ref_time;
        $pilot->kart_id = $request->kart_id;
        $pilot->save();
        return redirect('/pilot');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $pilot = \App\Pilot::find($id);
        $pilot->name = $request->get('name');
        $pilot->email = $request->get('first_name');
        $pilot->ref_time = $request->get('ref_time');
        $pilot->kart_id = $request->get('kart_id');
        $pilot->save();
        return redirect('/pilot');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id = null)
    {
        $pilot = \App\Pilot::find($id);
        $pilot->delete();

        return redirect('/pilot');
    }


    /**
     * Process datatables ajax request.
     *
     * @return \Illuminate\Http\JsonResponse
     */
    public function getPilotAllData()
    {
        return Datatables::of(
            Pilot::query()
                ->select('pilots.id', 'pilots.name', 'pilots.first_name', 'pilots.ref_time', 'karts.name  as kart_name')
                ->leftJoin('karts', 'kart_id', '=', 'karts.id')
        )->make();
    }

    /**
     * Process datatables ajax request.
     *
     * @return \Illuminate\Http\JsonResponse
     */
    public function getPilotsByKart(Request $request)
    {
        $id = $request->input('id');
        if ($id == null) {
            return self::getPilotAllData();
        } else {

            $request->session()->put('kartid', $id);

            return Datatables::of(
                Pilot::query()
                    ->select('pilots.id', 'pilots.name', 'pilots.first_name', 'pilots.ref_time', 'karts.name  as kart_name')
                    ->leftJoin('karts', 'kart_id', '=', 'karts.id')
                    ->where('karts.id', $id)
            )->make();
        }
    }
}
